[ARVADOS] updated: 1.3.0-3179-g2b3b1b59d

Git user git at public.arvados.org
Fri Sep 18 14:09:26 UTC 2020


Summary of changes:
 lib/dispatchcloud/{ssh_executor => sshexecutor}/executor.go      | 0
 lib/dispatchcloud/{ssh_executor => sshexecutor}/executor_test.go | 0
 2 files changed, 0 insertions(+), 0 deletions(-)
 rename lib/dispatchcloud/{ssh_executor => sshexecutor}/executor.go (100%)
 rename lib/dispatchcloud/{ssh_executor => sshexecutor}/executor_test.go (100%)

  discards  66e1e8f14c1efe653aa4762bd436e5eead5a0749 (commit)
       via  2b3b1b59dcd99e3b4940785f16c2c003419a2993 (commit)

This update added new revisions after undoing existing revisions.  That is
to say, the old revision is not a strict subset of the new revision.  This
situation occurs when you --force push a change and generate a repository
containing something like this:

 * -- * -- B -- O -- O -- O (66e1e8f14c1efe653aa4762bd436e5eead5a0749)
            \
             N -- N -- N (2b3b1b59dcd99e3b4940785f16c2c003419a2993)

When this happens we assume that you've already had alert emails for all
of the O revisions, and so we here report only the revisions in the N
branch from the common base, B.

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.


commit 2b3b1b59dcd99e3b4940785f16c2c003419a2993
Author: Ward Vandewege <ward at curii.com>
Date:   Thu Sep 17 17:03:01 2020 -0400

    Rename the ssh_executor package to sshexecutor, fix Golint warning.
    
    No issue #
    
    Arvados-DCO-1.1-Signed-off-by: Ward Vandewege <ward at curii.com>

diff --git a/build/run-tests.sh b/build/run-tests.sh
index 32d4a75d2..595f72108 100755
--- a/build/run-tests.sh
+++ b/build/run-tests.sh
@@ -88,7 +88,7 @@ lib/cloud/cloudtest
 lib/dispatchcloud
 lib/dispatchcloud/container
 lib/dispatchcloud/scheduler
-lib/dispatchcloud/ssh_executor
+lib/dispatchcloud/sshexecutor
 lib/dispatchcloud/worker
 lib/mount
 lib/pam
@@ -709,7 +709,7 @@ do_test() {
             stop_services
             check_arvados_config "$1"
             ;;
-        gofmt | doc | lib/cli | lib/cloud/azure | lib/cloud/ec2 | lib/cloud/cloudtest | lib/cmd | lib/dispatchcloud/ssh_executor | lib/dispatchcloud/worker)
+        gofmt | doc | lib/cli | lib/cloud/azure | lib/cloud/ec2 | lib/cloud/cloudtest | lib/cmd | lib/dispatchcloud/sshexecutor | lib/dispatchcloud/worker)
             check_arvados_config "$1"
             # don't care whether services are running
             ;;
diff --git a/lib/cloud/cloudtest/tester.go b/lib/cloud/cloudtest/tester.go
index 5288b5c76..087aceffa 100644
--- a/lib/cloud/cloudtest/tester.go
+++ b/lib/cloud/cloudtest/tester.go
@@ -12,7 +12,7 @@ import (
 	"time"
 
 	"git.arvados.org/arvados.git/lib/cloud"
-	"git.arvados.org/arvados.git/lib/dispatchcloud/ssh_executor"
+	"git.arvados.org/arvados.git/lib/dispatchcloud/sshexecutor"
 	"git.arvados.org/arvados.git/lib/dispatchcloud/worker"
 	"git.arvados.org/arvados.git/sdk/go/arvados"
 	"github.com/sirupsen/logrus"
@@ -48,7 +48,7 @@ type tester struct {
 	is              cloud.InstanceSet
 	testInstance    *worker.TagVerifier
 	secret          string
-	executor        *ssh_executor.Executor
+	executor        *sshexecutor.Executor
 	showedLoginInfo bool
 
 	failed bool
@@ -308,7 +308,7 @@ func (t *tester) waitForBoot(deadline time.Time) bool {
 // current address.
 func (t *tester) updateExecutor() {
 	if t.executor == nil {
-		t.executor = ssh_executor.New(t.testInstance)
+		t.executor = sshexecutor.New(t.testInstance)
 		t.executor.SetTargetPort(t.SSHPort)
 		t.executor.SetSigners(t.SSHKey)
 	} else {
diff --git a/lib/dispatchcloud/dispatcher.go b/lib/dispatchcloud/dispatcher.go
index 278bcb665..7614a143a 100644
--- a/lib/dispatchcloud/dispatcher.go
+++ b/lib/dispatchcloud/dispatcher.go
@@ -17,7 +17,7 @@ import (
 	"git.arvados.org/arvados.git/lib/cloud"
 	"git.arvados.org/arvados.git/lib/dispatchcloud/container"
 	"git.arvados.org/arvados.git/lib/dispatchcloud/scheduler"
-	"git.arvados.org/arvados.git/lib/dispatchcloud/ssh_executor"
+	"git.arvados.org/arvados.git/lib/dispatchcloud/sshexecutor"
 	"git.arvados.org/arvados.git/lib/dispatchcloud/worker"
 	"git.arvados.org/arvados.git/sdk/go/arvados"
 	"git.arvados.org/arvados.git/sdk/go/auth"
@@ -100,7 +100,7 @@ func (disp *dispatcher) Close() {
 
 // Make a worker.Executor for the given instance.
 func (disp *dispatcher) newExecutor(inst cloud.Instance) worker.Executor {
-	exr := ssh_executor.New(inst)
+	exr := sshexecutor.New(inst)
 	exr.SetTargetPort(disp.Cluster.Containers.CloudVMs.SSHPort)
 	exr.SetSigners(disp.sshKey)
 	return exr
diff --git a/lib/dispatchcloud/ssh_executor/executor_test.go b/lib/dispatchcloud/sshexecutor/executor_test.go
similarity index 99%
rename from lib/dispatchcloud/ssh_executor/executor_test.go
rename to lib/dispatchcloud/sshexecutor/executor_test.go
index b7f3aadd8..b4afeafa8 100644
--- a/lib/dispatchcloud/ssh_executor/executor_test.go
+++ b/lib/dispatchcloud/sshexecutor/executor_test.go
@@ -2,7 +2,7 @@
 //
 // SPDX-License-Identifier: AGPL-3.0
 
-package ssh_executor
+package sshexecutor
 
 import (
 	"bytes"

-----------------------------------------------------------------------


hooks/post-receive
diff --git a/lib/dispatchcloud/ssh_executor/executor.go b/lib/dispatchcloud/sshexecutor/executor.go
similarity index 98%
rename from lib/dispatchcloud/ssh_executor/executor.go
rename to lib/dispatchcloud/sshexecutor/executor.go
index 79b82e6c3..c37169921 100644
--- a/lib/dispatchcloud/ssh_executor/executor.go
+++ b/lib/dispatchcloud/sshexecutor/executor.go
@@ -2,9 +2,9 @@
 //
 // SPDX-License-Identifier: AGPL-3.0
 
 // Package ssh_executor provides an implementation of pool.Executor
 // using a long-lived multiplexed SSH session.
-package ssh_executor
+package sshexecutor
 
 import (
 	"bytes"
@@ -2,9 +2,9 @@
 // SPDX-License-Identifier: AGPL-3.0
 
-// Package ssh_executor provides an implementation of pool.Executor
+// Package sshexecutor provides an implementation of pool.Executor
 // using a long-lived multiplexed SSH session.
-- 




More information about the arvados-commits mailing list